@@ -1,7 +1,7 @@
 #' Tests for Multivariate Data in Semi-Parametric Factorial Designs
 #' 
-#' The MANOVA function calculates the Wald-type statistic (WTS), the ANOVA-type 
-#' statistic (ATS) and a modified ATS (MATS) as well as resampling versions of 
+#' The MANOVA function calculates the Wald-type statistic (WTS) and a modified ANOVA-type 
+#' statistic (MATS) as well as resampling versions of 
 #' these test statistics for 
 #' semi-parametric multivariate data.
 #' 
@@ -16,7 +16,7 @@
 #' @param alpha A number specifying the significance level; the default is 0.05.
 #' @param resampling The resampling method to be used, one of "paramBS"
 #'   (parametric bootstrap approach) and "WildBS" (wild bootstrap approach with
-#'   Rademacher weights). The Wild Bootstrap is calculated for all test statistics.
+#'   Rademacher weights).
 #' @param CPU The number of cores used for parallel computing. If omitted, cores are
 #'   detected via \code{\link[parallel]{detectCores}}.
 #' @param seed A random seed for the resampling procedure. If omitted, no 
@@ -25,14 +25,14 @@
 #'   are labeled uniquely or not. Default is FALSE, i.e., the levels of the nested 
 #'   factor are the same for each level of the main factor. For an example and more explanations
 #'   see the GFD package and the corresponding vignette.
-#'  
+#' @param dec Number of decimals the results should be rounded to. Default is 3.
 #'   
 #' @details The MANOVA() function provides the Wald-type statistic (WTS) as well as
-#'   the ANOVA-type statistic (ATS) for multivariate designs with metric data as described in 
-#'   Konietschke et al. (2015). Furthermore, it contains a modified ATS (MATS), which is invariant
+#'   the modified ANOVA-type statistic (MATS) for multivariate designs with metric data as described in 
+#'   Konietschke et al. (2015) and Friedrich and Pauly (2017), respectively. The MATS is invariant
 #'   under scale transformations of the components and applicable to designs with singular covariance
-#'   matrices, see Friedrich and Pauly (2017) for details.
-#'   These tests are even applicable for non-normal error terms, 
+#'   matrices.
+#'   Both tests are applicable for non-normal error terms, 
 #'   different sample sizes and/or heteroscedastic variances.
 #'   They are implemented for designs with an arbitrary number of
 #'   crossed factors or for nested designs. In addition to the asymptotic
@@ -49,14 +49,10 @@
 #'   \item{Covariance}{The estimated covariance matrix.} 
 #'   \item{WTS}{The value of the WTS along with degrees of freedom of the
 #'   central chi-square distribution and p-value.} 
-#'   \item{ATS}{The value of the
-#'   ATS, degrees of freedom of the central F distribution and the corresponding
-#'   p-value.}
 #'   \item{MATS}{The value of the MATS.} 
 #'   \item{resampling}{p-values for the test statistic based on the
 #'   chosen resampling approach.}
 #'  
-#'  
 #' @examples data(EEG)
 #' EEG_mod <- MANOVA(resp ~ sex * diagnosis, 
 #'                     data = EEG, subject = "id", resampling = "paramBS", 
@@ -76,9 +72,9 @@
 #'    Using EEG, SPECT, and Multivariate Resampling Methods
 #'    to Differentiate Between Alzheimer's and other Cognitive Impairments. arXiv preprint arXiv:1606.09004.
 #'   
-#'   Friedrich, S., Konietschke, F., Pauly, M. (2016). GFD - An 
-#'   R-package for the Analysis of General Factorial Designs. Accepted for publication in 
-#'   Journal of Statistical Software.
+#'   Friedrich, S., Konietschke, F., Pauly, M. (2017). GFD - An 
+#'   R-package for the Analysis of General Factorial Designs. 
+#'   Journal of Statistical Software, 79(1), 1-18.
 #'   
 #'   Friedrich, S., and Pauly, M. (2017). MATS: Inference for potentially singular and
 #'   heteroscedastic MANOVA. arXiv preprint arXiv:1704.03731.
@@ -96,7 +92,7 @@
 
 MANOVA <- function(formula, data, subject,
                    iter = 10000, alpha = 0.05, resampling = "paramBS", CPU,
-                   seed, nested.levels.unique = FALSE){
+                   seed, nested.levels.unique = FALSE, dec = 3){
   
   if (!(resampling %in% c("paramBS", "WildBS"))){
     stop("Resampling must be one of 'paramBS' and 'WildBS'!")
@@ -147,37 +143,29 @@ MANOVA <- function(formula, data, subject,
     n <- plyr::ddply(dat2, nadat2, plyr::summarise, Measure = length(unique(subject)),
                      .drop = F)$Measure
     WTS_out <- matrix(NA, ncol = 3, nrow = 1)
-    ATS_out <- matrix(NA, ncol = 4, nrow = 1)
     MATS_out <- NA
-    WTPS_out <- rep(NA, 3)
+    WTPS_out <- rep(NA, 2)
     quantiles <- matrix(NA, 2, 1)
     rownames(WTS_out) <- fac_names
-    rownames(ATS_out) <- fac_names
     names(WTPS_out) <- fac_names
     results <- MANOVA.Stat(data = response, n = n, hypo, iter = iter, alpha, resampling, n.groups = fl, p, CPU, seed, nf)    
-    WTS_out <- results$WTS
-    ATS_out <- results$ATS
-    MATS_out <- results$MATS
-    WTPS_out <- results$WTPS
+    WTS_out <- round(results$WTS, dec)
+    MATS_out <- round(results$MATS, dec)
+    WTPS_out <- round(results$WTPS, dec)
     quantiles <- results$quantiles
     names(quantiles) <- c("WTS_resampling", "MATS_resampling")
-    mean_out <- matrix(results$Mean, ncol = p, byrow = TRUE)
+    mean_out <- matrix(round(results$Mean, dec), ncol = p, byrow = TRUE)
     Var_out <- results$Cov
-    #    CI <- results$CI
-    #    colnames(CI) <- c("lower", "upper")
     descriptive <- cbind(lev_names, n, mean_out)
     colnames(descriptive) <- c(nadat2, "n", rep("Means", p))   
     names(WTS_out) <- cbind ("Test statistic", "df",
                              "p-value")
-    names(ATS_out) <- cbind("Test statistic", "df1", "df2", "p-value")
-    names(WTPS_out) <- cbind(paste(resampling, "(WTS)"), paste(resampling, "(ATS)"), paste(resampling, "(MATS)"))
+    names(WTPS_out) <- cbind(paste(resampling, "(WTS)"), paste(resampling, "(MATS)"))
     output <- list()
     output$input <- input_list
     output$Descriptive <- descriptive
-    #    output$CI <- CI
     output$Covariance <- Var_out
     output$WTS <- WTS_out
-    output$ATS <- ATS_out
     output$MATS <- MATS_out
     output$resampling <- WTPS_out
     output$quantile <- quantiles
@@ -189,7 +177,7 @@ MANOVA <- function(formula, data, subject,
     output$Means <- mean_out
     # end one-way layout ------------------------------------------------------
   } else {
-    dat2 <- dat2[do.call(order, dat2[, 2:(nf + 1)]), ]
+    dat2 <- dat2[do.call(order, dat2[, 2:(nf + 2)]), ]
     lev_names <- lev_names[do.call(order, lev_names[, 1:nf]), ]
     response <- dat2[, 1]
     nr_hypo <- attr(terms(formula), "factors")
@@ -201,7 +189,9 @@ MANOVA <- function(formula, data, subject,
                      .drop = F)
     n <- n$Measure/p
     
-    if (length(fac_names) == nf) {
+    nested <- grepl(":", formula)
+    
+    if (sum(nested) > 0) {
       # nested
       
       # if nested factor is named uniquely
@@ -252,7 +242,7 @@ MANOVA <- function(formula, data, subject,
            not implemented!")
     }
     # only 3-way nested designs are possible
-    if (length(fac_names) == nf && nf >= 4) {
+    if (sum(nested) > 0 && nf >= 4) {
       stop("Four- and higher way nested designs are
            not implemented!")
     }
@@ -262,47 +252,39 @@ MANOVA <- function(formula, data, subject,
            with less than 2 observations!")
     }
     
-    if (length(fac_names) != length(hypo_matrices)) {
-      stop("Something is wrong: Perhaps a missing interaction term in formula?")
-    }
-    
     #--------------------------------------------------------------------------#
     
     
     n.groups <- prod(fl)
     WTS_out <- matrix(NA, ncol = 3, nrow = length(hypo_matrices))
-    ATS_out <- matrix(NA, ncol = 4, nrow = length(hypo_matrices))
-    WTPS_out <- matrix(NA, nrow = length(hypo_matrices), ncol = 3)
+    WTPS_out <- matrix(NA, nrow = length(hypo_matrices), ncol = 2)
     MATS_out <- matrix(NA, nrow = length(hypo_matrices), ncol = 1)
     quantiles <- matrix(NA, ncol = 2, nrow = length(hypo_matrices))
     rownames(WTS_out) <- fac_names
-    rownames(ATS_out) <- fac_names
     rownames(WTPS_out) <- fac_names
     rownames(MATS_out) <- fac_names
     rownames(quantiles) <- fac_names
-    colnames(ATS_out) <- c("Test statistic", "df1", "df2", "p-value")
     colnames(MATS_out) <- "Test statistic"
     colnames(quantiles) <- c("WTS_resampling", "MATS_resampling")
     # calculate results
     for (i in 1:length(hypo_matrices)) {
       results <- MANOVA.Stat(data = response, n, hypo_matrices[[i]],
                              iter, alpha, resampling, n.groups, p, CPU, seed, nf)
-      WTS_out[i, ] <- results$WTS
-      ATS_out[i, ] <- results$ATS
-      WTPS_out[i, ] <- results$WTPS
-      MATS_out[i] <- results$MATS
+      WTS_out[i, ] <- round(results$WTS, dec)
+      WTPS_out[i, ] <- round(results$WTPS, dec)
+      MATS_out[i] <- round(results$MATS, dec)
       quantiles[i, ] <- results$quantiles
     }
     # time needed for resampling calculations
     time <- results$time
-    mean_out <- matrix(results$Mean, ncol = p, byrow = TRUE)
+    mean_out <- matrix(round(results$Mean, dec), ncol = p, byrow = TRUE)
     Var_out <- results$Cov
     descriptive <- cbind(lev_names, n, mean_out)
     colnames(descriptive) <- c(nadat2, "n", paste(rep("Mean", p), 1:p))
     
     # Output ------------------------------------------------------
     colnames(WTS_out) <- cbind ("Test statistic", "df", "p-value")
-    colnames(WTPS_out) <- cbind(paste(resampling, "(WTS)"), paste(resampling, "(ATS)"), paste(resampling, "(MATS)"))
+    colnames(WTPS_out) <- cbind(paste(resampling, "(WTS)"), paste(resampling, "(MATS)"))
     output <- list()
     output$time <- time
     output$input <- input_list
@@ -311,14 +293,12 @@ MANOVA <- function(formula, data, subject,
     output$Means <- mean_out
     output$MATS <- MATS_out
     output$WTS <- WTS_out
-    output$ATS <- ATS_out
     output$resampling <- WTPS_out
     output$quantile <- quantiles
     output$nf <- nf
     output$H <- hypo_matrices
     output$factors <- fac_names
     output$p <- p
-    output$fl <- fl
   }
   class(output) <- "MANOVA"
   return(output)
