@@ -1,5 +1,7 @@
-## function for calculating test statistics, permutation etc for repeated measures with only time as factor
-RM.Stat.oneway<- function(data, n, t, hypo_matrix, iter, alpha, resampling, seed){
+## function for calculating test statistics, permutation etc for repeated measures 
+# with only time as factor
+RM.Stat.oneway<- function(data, n, t, hypo_matrix, iter, alpha, resampling, 
+                          seed, CI.method){
   
   N <- n[1]
   H <- hypo_matrix
@@ -65,10 +67,18 @@ RM.Stat.oneway<- function(data, n, t, hypo_matrix, iter, alpha, resampling, seed
       
       TP <- t(H) %*% MASS::ginv(H %*% SnP %*% t(H)) %*% H
       WTPS <- diag(N * t(meansP) %*% TP %*% meansP)
+      # ATS
+      C <- t(H) %*% MASS::ginv(H %*% t(H)) %*% H
+      D <- diag(C) * diag(ncol(C))
+      spur <- sum(diag(C %*% SnP))
+      Lambda <- diag(1 / (n - 1))
+      ATS_res <- N / spur * t(meansP) %*% C %*% meansP
+      return(list(WTPS, ATS_res))
     })
-    ecdf_WTPS <- ecdf(WTPS)
+    ecdf_WTPS <- ecdf(unlist(WTPS[1, ]))
     p_valueWTPS <- 1-ecdf_WTPS(WTS)    
-    p_valueATS_res <- NA
+    ecdf_ATS_res <- ecdf(unlist(WTPS[2, ]))
+    p_valueATS_res <- 1-ecdf_ATS_res(ATS)
   } else if(resampling == "WildBS"){
     if(seed != 0){
       set.seed(seed)}
@@ -98,13 +108,21 @@ RM.Stat.oneway<- function(data, n, t, hypo_matrix, iter, alpha, resampling, seed
     p_valueATS_res <- 1-ecdf_ATS_res(ATS)     
   }
     
+  #------------------------ resampling quantile -------------------#
+  quant_WTS <- quantile(ecdf_WTPS, alpha)
+  
   #------------------------ p-values -------------------------------#
   p_valueWTS <- 1 - pchisq(abs(WTS), df = df_WTS)
   p_valueATS <- 1 - pf(abs(ATS), df1 = df_ATS, df2 = df_ATS2)
   
   #---------------------- CIs -------------------------------------#
-  CI_lower <- means - sqrt(diag(Sn) / n) * qt(1 - alpha / 2, df = n)
-  CI_upper <- means + sqrt(diag(Sn) / n) * qt(1 - alpha / 2, df = n)
+  if (CI.method == "t-quantile"){
+    CI_lower <- means - sqrt(diag(Sn) / n) * qt(1 - alpha / 2, df = n)
+    CI_upper <- means + sqrt(diag(Sn) / n) * qt(1 - alpha / 2, df = n)
+  } else if (CI.method == "resampling"){
+    CI_lower <- means - sqrt(diag(Sn) / n) * quant_WTS
+    CI_upper <- means + sqrt(diag(Sn) / n) * quant_WTS
+  }
   
   #-------------------- Output ----------------------------------#
   WTS_out <- c(WTS, df_WTS, p_valueWTS)
